@@ -1,9 +1,9 @@
-# $Id: test.pl,v 1.5 2001/05/03 01:13:50 btrott Exp $
+# $Id: test.pl,v 1.6 2001/07/21 05:32:42 btrott Exp $
 
 use strict;
 
 use Test;
-BEGIN { plan tests => 33 }
+BEGIN { plan tests => 45 }
 
 use vars qw( $loaded );
 END { print "not ok 1\n" unless $loaded; }
@@ -27,6 +27,8 @@ ok($buffer->get_int32, 999999999);
 $buffer->put_int8(2);
 ok($buffer->get_int8, 2);
 
+my $save_off = $buffer->offset;
+
 $buffer->put_int16(9999);
 ok($buffer->get_int16, 9999);
 
@@ -38,8 +40,20 @@ ok($buffer->get_char, 'b');
 ok($buffer->get_char, 'a');
 ok($buffer->get_char, 'r');
 
+$buffer->put_bytes("foobar", 5);
+ok($buffer->get_bytes(5), "fooba");
+ok($buffer->offset == $buffer->length);
+
+$buffer->{offset} = $save_off;
+my $buf2 = $buffer->extract(5);
+ok($buf2->offset, 0);
+ok($buf2->length, 5);
+ok($buf2->get_int16, 9999);
+ok($buf2->get_bytes(3), 'aba');
+
 $buffer->insert_template;
 my @data = $buffer->get_all;
+ok(@data == 14);
 ok($data[0], "foo");
 ok($data[1], 0);
 ok($data[2], 999999999);
@@ -49,6 +63,11 @@ ok($data[5], 'a');
 ok($data[6], 'b');
 ok($data[7], 'a');
 ok($data[8], 'r');
+ok($data[9], 'f');
+ok($data[10], 'o');
+ok($data[11], 'o');
+ok($data[12], 'b');
+ok($data[13], 'a');
 
 $buffer->empty;
 ok($buffer->offset, 0);
